src/hotspot/share/runtime/thread.cpp
changeset 47614 0ecfd6c951a6
parent 47613 af241e3e5a13
child 47634 6a0c42c40cd1
--- a/src/hotspot/share/runtime/thread.cpp	Tue Oct 10 11:52:42 2017 -0700
+++ b/src/hotspot/share/runtime/thread.cpp	Tue Oct 10 14:38:56 2017 -0700
@@ -3751,8 +3751,8 @@
   // Final system initialization including security manager and system class loader
   call_initPhase3(CHECK_JNI_ERR);
 
-  // cache the system class loader
-  SystemDictionary::compute_java_system_loader(CHECK_(JNI_ERR));
+  // cache the system and platform class loaders
+  SystemDictionary::compute_java_loaders(CHECK_JNI_ERR);
 
 #if INCLUDE_JVMCI
   if (EnableJVMCI) {